==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/collection/request/DataLossPreventionPolicyCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.ActionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.complex.DlpEvaluationInput;
import odata.msgraph.client.beta.complex.DlpNotification;
import odata.msgraph.client.beta.entity.DataLossPreventionPolicy;
import odata.msgraph.client.beta.entity.DlpEvaluatePoliciesJobResponse;
import odata.msgraph.client.beta.entity.request.DataLossPreventionPolicyRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

public class DataLossPreventionPolicyCollectionRequest extends CollectionPageEntityRequest<DataLossPreventionPolicy, DataLossPreventionPolicyRequest>{

    protected ContextPath contextPath;

    public DataLossPreventionPolicyCollectionRequest(ContextPath contextPath) {
        super(contextPath, DataLossPreventionPolicy.class, cp -> new DataLossPreventionPolicyRequest(cp), SchemaInfo.INSTANCE);
        this.contextPath = contextPath;
    }

    @Action(name = "evaluate")
    @JsonIgnore
    public ActionRequestReturningNonCollectionUnwrapped<DlpEvaluatePoliciesJobResponse> evaluate(String target, DlpEvaluationInput evaluationInput, DlpNotification notificationInfo) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("target", "Edm.String", Checks.checkIsAscii(target))
            .put("evaluationInput", "microsoft.graph.dlpEvaluationInput", evaluationInput)
            .put("notificationInfo", "microsoft.graph.dlpNotification", notificationInfo)
            .build();
        return new ActionRequestReturningNonCollectionUnwrapped<DlpEvaluatePoliciesJobResponse>(this.contextPath.addActionOrFunctionSegment("microsoft.graph.evaluate"), DlpEvaluatePoliciesJobResponse.class, _parameters, odata.msgraph.client.beta.schema.SchemaInfo.INSTANCE);
    }

}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/collection/request/DataLossPreventionPolicyCollectionRequest.java <==
package odata.msgraph.client.beta.entity.collection.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.github.davidmoten.odata.client.ActionRequestReturningNonCollectionUnwrapped;
import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.complex.DlpEvaluationInput;
import odata.msgraph.client.beta.complex.DlpNotification;
import odata.msgraph.client.beta.entity.DataLossPreventionPolicy;
import odata.msgraph.client.beta.entity.DlpEvaluatePoliciesJobResponse;
import odata.msgraph.client.beta.entity.request.DataLossPreventionPolicyRequest;

public class DataLossPreventionPolicyCollectionRequest extends CollectionPageEntityRequest<DataLossPreventionPolicy, DataLossPreventionPolicyRequest>{

    protected ContextPath contextPath;

    public DataLossPreventionPolicyCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, DataLossPreventionPolicy.class, cp -> new DataLossPreventionPolicyRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    @Action(name = "evaluate")
    @JsonIgnore
    public ActionRequestReturningNonCollectionUnwrapped<DlpEvaluatePoliciesJobResponse> evaluate(String target, DlpEvaluationInput evaluationInput, DlpNotification notificationInfo) {
        Map<String, TypedObject> _parameters = ParameterMap
            .put("target", "Edm.String", Checks.checkIsAscii(target))
            .put("evaluationInput", "microsoft.graph.dlpEvaluationInput", evaluationInput)
            .put("notificationInfo", "microsoft.graph.dlpNotification", notificationInfo)
            .build();
        return new ActionRequestReturningNonCollectionUnwrapped<DlpEvaluatePoliciesJobResponse>(this.contextPath.addActionOrFunctionSegment("microsoft.graph.evaluate"), DlpEvaluatePoliciesJobResponse.class, _parameters);
    }

}
